﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;

public class PlayerScript : MonoBehaviour
{

    //Player movimentation variables  
    [SerializeField]
    private float _velocidade = 6f; //Variavel que regula a velocidade de movimento do jogador.
    private Vector3 _movimento; //Variavel que vai guardar o movimento do jogador.
    private CharacterController _controle; //Variavel que referencia ao componente Character Controller.

    //Player Jump variables
    [SerializeField]
    private float _gravidade = 10f; //Variavel que simula a gravidade para o jogador.
    [SerializeField]
    private float _velocidadeDeQueda; //Variavel que controla a queda do jogador.

  
    public bool teste;

    //Player Rotation Variables
    [SerializeField]
    private float _turnSpeed = 10f;
    [SerializeField]
    private float _angle;


    public Transform cam;

    [SerializeField]
    public int life = 3;

    private UIManager _uiManager;

    
    public bool canMove = true;

    private AudioManager _audioManager;

    // Use this for initialization
    void Start()
    { // Procedimento que é rodado no inicio do jogo.
        _controle = GetComponent<CharacterController>(); //controle é referenciado ao componente CharacterController
        cam = Camera.main.transform;

        Cursor.visible = false;
        Cursor.lockState = CursorLockMode.Locked;

        _uiManager = GameObject.Find("Canvas").GetComponent<UIManager>();

        _audioManager = GameObject.Find("AudioManager").GetComponent<AudioManager>();
    }

    // Update is called once per frame
    void Update()
    {

        //Input Variables
        float moveHorizontal = Input.GetAxisRaw("Horizontal"); // pega a leitura do teclado das teclas A e D que representam movimento horizontal, A = -1; b = 1; nenhuma delas = 0.
        float moveVertical = Input.GetAxisRaw("Vertical"); //pega a leitura das teclas W e S que representam movimento vertical, S = -1; W = 1; nenhuma delas = 0;
        //float pulo = Input.GetAxisRaw("Jump"); //Pega a leitura da tecla Espaço
        
        if (Input.GetKey("escape"))
        {
            Cursor.visible = true;
            Cursor.lockState = CursorLockMode.None;
        }

        CalculateDirection(moveHorizontal, moveVertical);

        if (canMove == true) {
            Movimentar(moveHorizontal, moveVertical); //Chama o procedimento que vai movimentar o jogador.

            Rotate(moveHorizontal, moveVertical);
        }
    }


    void Movimentar(float moveHorizontal, float moveVertical) //Procedimento que movimenta o jogador.
    {


        if (!_controle.isGrounded) //Checa se o usuário está ou não no chão.
        {
            _velocidadeDeQueda -= _gravidade * Time.deltaTime; //Se ele não estiver velocidadeDeQueda é subtraido pela gravidade por segundo.
            teste = false;
        }
        else //Caso contrário o jogador está no chão
        {
            _velocidadeDeQueda = 0; //Velocidade de queda é zerado
            teste = true;
        }

        Vector3 camF = cam.forward;
        Vector3 camR = cam.right;

        camF.y = 0;
        camR.y = 0;

        camF = camF.normalized;
        camR = camR.normalized;

        _movimento = (camF * moveVertical) + (camR * moveHorizontal);


        _movimento = _movimento.normalized * _velocidade + Vector3.up * _velocidadeDeQueda; //Normalisa o movimento e aplica velocidade.

        _controle.Move(_movimento * Time.deltaTime); //Realiza o movimento por segundo.

        if (transform.position.y < -50f)
        {
            transform.position = new Vector3(0, 2, 0);
            Damage();
            _uiManager.HeartDown(life);
        }

    }

    void CalculateDirection(float moveHorizontal, float moveVertical)
    {
        _angle = Mathf.Atan2(moveHorizontal, moveVertical);

        _angle = Mathf.Rad2Deg * _angle;

        _angle += cam.eulerAngles.y;
    }

    void Rotate(float moveHorizontal, float moveVertical)
    {
        if (moveHorizontal != 0 || moveVertical != 0)
        {

            Quaternion target = Quaternion.Euler(moveHorizontal, _angle, moveVertical);
            transform.rotation = Quaternion.Slerp(transform.rotation, target, _turnSpeed * Time.deltaTime);
        }
    }

    public void Damage()
    {
        life--;
        if (life < 1)
        {
            _audioManager.Stop("Main Theme");
            _audioManager.Play("Game Over");
            _uiManager.GameOverPanelOn();
        }
        _uiManager.HeartDown(life);
    }

    public void LifeUp()
    {
        if (life < 3)
        {
            life++;
            _uiManager.HeartUp(life - 1);
        }
    }

}

//Notas:
//A diferença entre GetAxis e GetAxisRaw é que GetAxis le o que o jogador entra no teclado e sobe gradativamente de 0 a 1.
// GetAxisRaw só pega valores -1, 0, 1. Sendo -1 esquerda ou para baixo e 1 direita ou em cima em seus respectivos eixos.

//.normalized retorna o vetor com valor apenas de magnitude 1. Foi usado parar normalisar o movimento do personagem,
// sem essa função o jogador poderia se mover mais rápido na diagonal. Por exemplo se o jogador pressionar W e D a
//resultante disso seria 1.4, fazendo o se mover mais rapido na diagonal.

//Time.deltaTime da o tempo em segundos entre quadros, o padrão é 30 ou 60 quadros por segundo mas esse valor pode variar. É utilizado para normalisar o movimento.

//Mathf.Sqrt faz a raiz quadrada de alguma coisa.