﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using UnityEngine.UI;
using UnityEngine.SceneManagement;

public class UIManager : MonoBehaviour {

    [SerializeField]
    private Image _menu;

    [SerializeField]
    private GameObject[] _buttons;

    private bool _isPaused = false;

    [SerializeField]
    private RawImage[] _hearts;

    [SerializeField]
    private GameObject _gameOverPanel;

    private AudioManager _audioManager;

    [SerializeField]
    private GameObject _chooseLevelCanvas;
    private void Start()
    {
        _audioManager = GameObject.Find("AudioManager").GetComponent<AudioManager>();
    }

    // Update is called once per frame
    void Update () {
        if (Input.GetKeyDown(KeyCode.P) || Input.GetKeyDown(KeyCode.Escape))
        {
            if (_isPaused == false)
            {
                PauseGame();
            }
            else
            {
                ResumeGame();
            }
        }
	}

    private void PauseGame()
    {
        Time.timeScale = 0;
        _menu.gameObject.SetActive(true);
        _isPaused = true;
        Cursor.visible = true;
        Cursor.lockState = CursorLockMode.None;
        _menu.enabled = true;

        for (int i = 0; i < 4; i++)
        {
            _buttons[i].SetActive(true);
        }
    }

    public void ResumeGame()
    {
        _isPaused = false;
        _menu.gameObject.SetActive(false);
        Time.timeScale = 1;
        Cursor.visible = false;
        Cursor.lockState = CursorLockMode.Locked;
        _menu.enabled = false;

        for (int i = 0; i < 4; i++)
        {
            _buttons[i].SetActive(false);
        }
    }

    public void ReturnMainMenu()
    {
        Time.timeScale = 1;
        SceneManager.LoadScene("MainMenu");
    }

    public void HeartDown(int heart)
    {
        _hearts[heart].color = new Color(1f, 0, 0, 0.2f);
    }

    public void HeartUp(int heart)
    {
        _hearts[heart].color = new Color(1f, 1f, 1f, 1f);
    }

    public void GameOverPanelOn()
    {
        _gameOverPanel.gameObject.SetActive(true);
        Cursor.visible = true;
        Cursor.lockState = CursorLockMode.None;
    }

    public void GameOverPanelOff()
    {
        _gameOverPanel.gameObject.SetActive(false);
        Cursor.visible = false;
        Cursor.lockState = CursorLockMode.Locked;
    }

    public void GameOverContinueButton()
    {
        SceneManager.LoadScene(SceneManager.GetActiveScene().buildIndex);
    }

    public void RestartLevel() //Reinicia o level 
    {
        Time.timeScale = 1;
        Scene scene = SceneManager.GetActiveScene();
        SceneManager.LoadScene(scene.buildIndex);

    }

    public void PlayHoverMouseSound()
    {
        _audioManager.PlayOneShot("UI Mouse Hover");
    }

    public void PlayOnClick()
    {
        _audioManager.Play("UI Mouse Click");
    }

    public void ChooseLevelOn()
    {
        _chooseLevelCanvas.SetActive(true);
    }

    public void ChooseLevelOff()
    {
        _chooseLevelCanvas.SetActive(false);
    }
}
