﻿using UnityEngine;

public class DoorScript : MonoBehaviour
{
    [SerializeField]
    private GameObject _doorR;
    [SerializeField]
    private GameObject _doorL;

    private float _speed = 1f;
    [SerializeField]
    private bool _open = false;

    private Vector3 _initialPositionDoorR;
    private Vector3 _initialPositionDoorL;
    private Vector3 _endPositionDoorR;
    private Vector3 _endPositionDoorL;

    private ProjectorScript _projectorScript;

    [SerializeField]
    private int _doorId;

    private OpenDoorManager _openDoorManager;

    private AudioManager _audioManager;
    private bool _playAudioOnceOpen = false;
    private bool _playAudioOnceClose = false;

    void Start()
    {
        _initialPositionDoorR = _doorR.transform.position;
        _initialPositionDoorL = _doorL.transform.position;

        if (_doorId == 3)
        {
            _endPositionDoorR.y = _initialPositionDoorR.y + 1.36f;
            _endPositionDoorL.y = _initialPositionDoorL.y - 2.0f;
        }
        else
        {
            _endPositionDoorR.x = _initialPositionDoorR.x - 1.36f;
            _endPositionDoorL.x = _initialPositionDoorL.x + 1.36f;
        }

        _projectorScript = GameObject.Find("projector").GetComponent<ProjectorScript>();

        _openDoorManager = GameObject.Find("Door Manager").GetComponent<OpenDoorManager>();

        _audioManager = GameObject.Find("AudioManager").GetComponent<AudioManager>();
    }

    // Update is called once per frame
    void Update()
    {
        if (_open == true)
        {
            if (_openDoorManager.door[_doorId-1] == 1)
            {
                OpenRightDoor();
                if (_playAudioOnceOpen == false)
                {
                    _audioManager.PlayOneShot("Door Open");
                    _playAudioOnceOpen = true;
                }
            }
        }
        else
        {
            CloseDoor();
        }
    }

    private void OnTriggerEnter(Collider other)
    {
        if (other.tag == "Player")
        {
            _open = true;
            _playAudioOnceClose = false;
        }
    }

    private void OnTriggerExit(Collider other)
    {
        if (other.tag == "Player")
        {
            _open = false;
            _playAudioOnceOpen = false;
            if (_playAudioOnceClose == false && _openDoorManager.door[_doorId - 1] == 1)
            {
                _audioManager.PlayOneShot("Door Close");
                _playAudioOnceClose = true;
            }
        }   
    }

    private void OpenRightDoor()
    {

        if ((_doorR.transform.position.x > _endPositionDoorR.x) && _doorId != 3)
        {
            _doorR.transform.Translate(Vector3.left * _speed * 2 * Time.deltaTime);
            _doorL.transform.Translate(Vector3.right * _speed * 2 * Time.deltaTime);
        }
        else
        {
            if (_doorL.transform.position.y > _endPositionDoorL.y)
            {
                _doorR.transform.Translate(Vector3.up * _speed * 2 * Time.deltaTime);
                _doorL.transform.Translate(Vector3.down * _speed * 2 * Time.deltaTime);
            }
        }
    }

    private void CloseDoor()
    {
        
        if ((_doorR.transform.position.x < _initialPositionDoorR.x) && _doorId != 3)
        {
            _doorR.transform.Translate(Vector3.right * _speed * 2 * Time.deltaTime);
            _doorL.transform.Translate(Vector3.left * _speed * 2 * Time.deltaTime);
        }
        else
        {
            if (_doorL.transform.position.y < _initialPositionDoorL.y)
            {
                _doorR.transform.Translate(Vector3.down * _speed * 2 * Time.deltaTime);
                _doorL.transform.Translate(Vector3.up * _speed * 2 * Time.deltaTime);
            }
        }
    }
}
