﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using UnityEngine.UI;

public class ProjectorScript : MonoBehaviour
{
    [SerializeField]
    private GameObject _whiteMouseCanvas;
    [SerializeField]
    private GameObject _projectorCanvas;
    [SerializeField]
    private GameObject _cubeImage;
    [SerializeField]
    private GameObject _sphereImage;
    [SerializeField]
    private GameObject _pyramidImage;

    private KeyManagers _keyManagers;

    public bool projectorDone = false;

    private GreenLight _greenlight;
    private GreenLight _greenlightSecond;
    private GreenLight _greenLightThird;

    private CameraController _cameraController;
    private PlayerScript _playerScript;

    private AudioManager _audioManager;
    private bool _playSoundOnce = false;

    [SerializeField]
    private Image _arrowImage;
    private void Start()
    {
        _keyManagers = GameObject.Find("KeysManager").GetComponent<KeyManagers>();
        _greenlight = GameObject.Find("Light Wall").GetComponent<GreenLight>();
        _greenlightSecond = GameObject.Find("Light Wall 2").GetComponent<GreenLight>();
        _greenLightThird = GameObject.Find("Light Wall 3").GetComponent<GreenLight>();
        _cameraController = GameObject.Find("Main Camera").GetComponent<CameraController>();
        _playerScript = GameObject.Find("Player").GetComponent<PlayerScript>();
        _audioManager = GameObject.Find("AudioManager").GetComponent<AudioManager>();
    }

    private void OnTriggerEnter(Collider other)
    {
        if (other.tag == "Player")
        {
            _whiteMouseCanvas.SetActive(true);
        }
    }

    private void OnTriggerStay(Collider other)
    {
        if ((other.tag == "Player") && (Input.GetMouseButtonDown(0)))
        {
            _projectorCanvas.SetActive(true);
            _whiteMouseCanvas.SetActive(false);
            if (_keyManagers.cubeImage == true)
            {
                _cubeImage.SetActive(true);
                if (_arrowImage != null)
                {
                    _arrowImage.gameObject.SetActive(true);
                }
            }
            if (_keyManagers.sphereImage == true)
            {
                _sphereImage.SetActive(true);
            }
            if (_keyManagers.pyramidImage == true)
            {
                _pyramidImage.SetActive(true);
            }
            Cursor.visible = true;
            Cursor.lockState = CursorLockMode.None;
            _cameraController.active = false;
            _playerScript.canMove = false;
            if (_playSoundOnce == false)
            {
                _audioManager.PlayOneShot("Sci-fi Projector");
                _playSoundOnce = true;
            }

        }
        if ((other.tag == "Player") && (Input.GetKey(KeyCode.Escape)))
        {
            CloseCanvas();
        }


    }

    private void OnTriggerExit(Collider other)
    {
        if (other.tag == "Player")
        {
            _whiteMouseCanvas.SetActive(false);
            this.gameObject.transform.Find("Projector Canvas").gameObject.SetActive(false);
            Cursor.visible = false;
            Cursor.lockState = CursorLockMode.Locked;
            _cameraController.active = true;
            _playerScript.canMove = true;
            _playSoundOnce = false;
        }
    }

    public void CloseCanvas()
    {
        this.gameObject.transform.Find("Projector Canvas").gameObject.SetActive(false);
        _cameraController.active = true;
        _playerScript.canMove = true;
        _whiteMouseCanvas.SetActive(true);
        Cursor.visible = false;
        Cursor.lockState = CursorLockMode.Locked;
        _playSoundOnce = false;
    }

    public void ProjectorComunicationWithDoorLight()
    {
        if (_keyManagers.keyCount == 1)
        {
            _greenlight.SetGreen();
        }
        if (_keyManagers.keyCount == 2)
        {
            _greenlightSecond.SetGreen();
        }
        if (_keyManagers.keyCount == 3)
        {
            _greenLightThird.SetGreen();
        }
    }

}
