﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using UnityEngine.UI;

public class PanelScript2 : MonoBehaviour
{
    [SerializeField]
    private Image _whiteMouse;
    [SerializeField]
    private Camera _mainCamera;
    [SerializeField]
    private Camera _secondaryCamera;
    [SerializeField]
    private Text _textButton;
    [SerializeField]
    private GameObject[] _cubes;

    private PlayerScript _playerScript;

    private bool _panel = false;

    [SerializeField]
    private GameObject _panelPanel;

    [SerializeField]
    private int _count;

    private AudioManager _audioManager;

    // Use this for initialization
    void Start()
    {
        _playerScript = GameObject.Find("Player").GetComponent<PlayerScript>();
        _audioManager = GameObject.Find("AudioManager").GetComponent<AudioManager>();
    }

    private void OnTriggerEnter(Collider other)
    {
        if (other.tag == "Player")
        {
            _whiteMouse.gameObject.SetActive(true);
        }
    }

    private void OnTriggerExit(Collider other)
    {
        if (other.tag == "Player")
        {
            _whiteMouse.gameObject.SetActive(false);
        }
    }

    private void OnTriggerStay(Collider other)
    {
        if ((other.tag == "Player") && (Input.GetKeyDown(KeyCode.E) || Input.GetMouseButtonDown(0)))
        {
            if (_panel == false)
            {
                _panel = true;
                _playerScript.canMove = false;
                _whiteMouse.gameObject.SetActive(false);
                _secondaryCamera.enabled = true;
                _mainCamera.enabled = false;
                ShowPanel();
                _audioManager.PlayOneShot("Computer On");
                Cursor.visible = true;
                Cursor.lockState = CursorLockMode.None;
            }
            else if (other.tag == "Player" && Input.GetKeyDown(KeyCode.E)) 
            {
                ClosePanel();
                _audioManager.PlayOneShot("Computer Off");
            }
        }
    }

    private void ShowPanel()
    {
        _panelPanel.gameObject.SetActive(true);
    }

    private void HidePanel()
    {
        _panelPanel.gameObject.SetActive(false);
    }

    public void PlusCount()
    {
        if (_count < 9)
        {
            _count++;
            UpdateCountText();
            UpdateCubes();
            _audioManager.PlayOneShot("Cube Plus");
        }
    }

    public void MinusCount()
    {
        if (_count > 0)
        {
            _count--;
            UpdateCountText();
            UpdateCubes();
            _audioManager.PlayOneShot("Cube Minus");
        }
    }

    private void UpdateCountText()
    {
        _textButton.text = "" + _count;
    }

    private void UpdateCubes()
    {
        for (int i = 0; i < 9; i++)
        {
            if (i < _count)
            {
                _cubes[i].gameObject.SetActive(true);
            }
            else
            {
                _cubes[i].gameObject.SetActive(false);
            }
        }
    }

    public void ClosePanel()
    {
        _panel = false;
        _playerScript.canMove = true;
        _whiteMouse.gameObject.SetActive(true);
        _secondaryCamera.enabled = false;
        _mainCamera.enabled = true;
        HidePanel();
        _audioManager.PlayOneShot("Computer Off");
        Cursor.visible = false;
        Cursor.lockState = CursorLockMode.Locked;
    }

}
