﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using UnityEngine.UI;

public class PanelScript4 : MonoBehaviour
{
    [SerializeField]
    private Image _whiteMouseButton;
    [SerializeField]
    private Camera _mainCamera;
    [SerializeField]
    private Camera _secondaryCamera;
    [SerializeField]
    private Text _textButton;
    [SerializeField]
    private GameObject[] _cubes;

    private PlayerScript _playerScript;

    private bool _panel = false;

    [SerializeField]
    private GameObject _panelPanel;

    [SerializeField]
    private int _count;

    [SerializeField]
    private Button _button4;
    [SerializeField]
    private Button _button5;
    [SerializeField]
    private Button _button6;
    [SerializeField]
    private Button _button3;

    [SerializeField]
    private int _maxCubes;

    private bool _alreadyPressed4 = false;
    private bool _alreadyPressed5 = false;
    private bool _alreadyPressed6 = false;
    private bool _alreadyPressed3 = false;

    private AudioManager _audioManager;

    // Use this for initialization
    void Start()
    {
        _playerScript = GameObject.Find("Player").GetComponent<PlayerScript>();
        _audioManager = GameObject.Find("AudioManager").GetComponent<AudioManager>();
    }

    private void Update()
    {
        if (_playerScript.life < 1)
        {
            HidePanel();
        }
    }

    private void OnTriggerEnter(Collider other)
    {
        if (other.tag == "Player")
        {
            _whiteMouseButton.gameObject.SetActive(true);
        }
    }

    private void OnTriggerExit(Collider other)
    {
        if (other.tag == "Player")
        {
            _whiteMouseButton.gameObject.SetActive(false);
        }
    }

    private void OnTriggerStay(Collider other)
    {
        if ((other.tag == "Player") && (Input.GetKeyDown(KeyCode.E) || Input.GetMouseButtonDown(0)))
        {
            if (_panel == false)
            {
                _panel = true;
                _playerScript.canMove = false;
                _whiteMouseButton.gameObject.SetActive(false);
                _secondaryCamera.enabled = true;
                _mainCamera.enabled = false;
                ShowPanel();
                _audioManager.PlayOneShot("Computer On");
                Cursor.visible = true;
                Cursor.lockState = CursorLockMode.None;
            }
            else if (other.tag == "Player" && Input.GetKeyDown(KeyCode.E))
            {
                ClosePanel();
                _audioManager.PlayOneShot("Computer Off");
            }
        }
    }

    private void ShowPanel()
    {
        _panelPanel.gameObject.SetActive(true);
    }

    private void HidePanel()
    {
        _panelPanel.gameObject.SetActive(false);
    }

    public void RightButton()
    {
        _count = 3;
        UpdateCountText();
        UpdateCubes();
        _button3.image.color = Color.green;
        if (_alreadyPressed3 == false)
        {
            _playerScript.LifeUp();
            _alreadyPressed3 = true;
            _audioManager.PlayOneShot("Right");
        }
    }

    public void WrongButton4()
    {
        _button4.image.color = Color.red;
        if (_alreadyPressed4 == false)
        {
            _playerScript.Damage();
            _alreadyPressed4 = true;
            _audioManager.PlayOneShot("Wrong");
        }
    }

    public void WrongButton5()
    {
        _button5.image.color = Color.red;
        if (_alreadyPressed5 == false)
        {
            _playerScript.Damage();
            _alreadyPressed5 = true;
            _audioManager.PlayOneShot("Wrong");
        }
    }

    public void WrongButton6()
    {
        _button6.image.color = Color.red;
        if (_alreadyPressed6 == false)
        {
            _playerScript.Damage();
            _alreadyPressed6 = true;
            _audioManager.PlayOneShot("Wrong");
        }
    }

    private void UpdateCountText()
    {
        _textButton.text = "" + _count;
    }

    private void UpdateCubes()
    {
        for (int i = 0; i < _maxCubes; i++)
        {
            if (i < _count)
            {
                _cubes[i].gameObject.SetActive(true);
            }
            else
            {
                _cubes[i].gameObject.SetActive(false);
            }
        }
    }

    public void ClosePanel()
    {
        _panel = false;
        _playerScript.canMove = true;
        _whiteMouseButton.gameObject.SetActive(true);
        _secondaryCamera.enabled = false;
        _mainCamera.enabled = true;
        HidePanel();
        _audioManager.PlayOneShot("Computer Off");
        Cursor.visible = false;
        Cursor.lockState = CursorLockMode.Locked;
    }
}