﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using UnityEngine.UI;

public class SignScript : MonoBehaviour {

    [SerializeField]
    private Image _eKeyboard;
    [SerializeField]
    private GameObject _signPanel;
    private bool _panelActive = false;

    private PlayerScript _playerScript;
    private CameraController _cameraController;

    [SerializeField]
    private RawImage[] _images;

    [SerializeField]
    private float _time;
    private float _timer = 0;
    private bool _timerBool = false; //Referente a variavel _timer
    private bool _timeBool = false; //Referente a variavel _time e a corotina

    private float _timeRate = 1.5f;
    private int _timeCount = 0;

    [SerializeField]
    private Text _numbers;

    [SerializeField]
    private int _signID;

    [SerializeField]
    private float _R; //Red
    [SerializeField]
    private float _G; //Green
    [SerializeField]
    private float _B; //Blue

    private float _rRate;
    private float _gRate;
    private float _bRate;

    private Level1Manager _level1Manager;

    private bool _signRepead = false;

    private AudioManager _signAudioManager;
    private AudioManager _audioManager;

    [SerializeField]
    private GameObject _3DNumber;

    private bool _alreadyVisited = false;
    private bool _alreadyPlayedSound = false;

    void Start()
    {
        _playerScript = GameObject.Find("Player").GetComponent<PlayerScript>();
        _cameraController = GameObject.Find("Main Camera").GetComponent<CameraController>();

        _time *= _signID;
        _time += 1.5f;

        _level1Manager = GameObject.Find("LevelManager").GetComponent<Level1Manager>();

        //RGB 255 -> 1 (mudando formato)
        if (_R != 0)
        {
            _R = _R / 255;
        }

        if (_G != 0)
        {
            _G = _G / 255;
        }

        if (_B != 0)
        {
            _B = _B / 255;
        }

        //Dividindo RGB em pedaços
        if (_R != 0)
        {
            _R = _R / _signID;
        }

        if (_G != 0)
        {
            _G = _G / _signID;
        }

        if (_B != 0)
        {
            _B = _B / _signID;
        }

        _rRate = _R;
        _gRate = _G;
        _bRate = _B;

        _signAudioManager = GameObject.Find("SignAudioManager").GetComponent<AudioManager>();
        _audioManager = GameObject.Find("AudioManager").GetComponent<AudioManager>();
    }

    void Update()
    {

        if (_timerBool == true )
        {
            _timer += Time.deltaTime;

            if ((_timer >= _timeRate) && (_timeCount < _signID))
            {
                
                _images[_timeCount].color = new Color(1f, 1f, 1f, 1f);

                int soundNumber = _timeCount + 1;
                string soundString;
                soundString = soundNumber.ToString();

                _numbers.color = new Color(_R, _G, _B, 1f);

                _R += _rRate;
                _G += _gRate;
                _B += _bRate;

                _numbers.text = _timeCount+1 + "";
                _signAudioManager.PlayOneShot(soundString);
                _timeCount++;
             
                _timeRate += 1.5f;
            }
        }      
    }

    void OnTriggerEnter(Collider other)
    {
        if (other.tag == "Player")
        {
            ShowEKeyboard();
        }
    }

    void OnTriggerExit(Collider other)
    {
        if (other.tag == "Player")
        {
            HideEKeyboard();
            HidePanel();
        }
    }

    private void OnTriggerStay(Collider other)
    {
        if ((other.tag == "Player") && Input.GetMouseButton(0))
        {
            if (_panelActive == false)
            {
                _audioManager.PlayOneShot("Page Sound");
                ShowPanel();
                HideEKeyboard();
                _playerScript.canMove = false;
                _cameraController.active = false;
                _timer = 0f;
                _timerBool = true;
                StartCoroutine(WaitTime());

                if (_signRepead == false)
                {
                    _signRepead = true;
                }
            }
        }
        else if (other.tag == "Player")
        {
            if (_timeBool == true)
            {
                _3DNumber.SetActive(true);
                _playerScript.canMove = true;
                _cameraController.active = true;
                HidePanel();
                ShowEKeyboard();
                _timeBool = false;
                _timeRate = 1.5f;
                if (_alreadyVisited == false)
                {
                    _audioManager.PlayOneShot("Magical Number");
                    _level1Manager.signsRead++;
                    _level1Manager.UpdateLevel1UI();
                    _level1Manager.EndLevelCheck();
                    _alreadyVisited = true;
                }
            }
        }
    }

    private void ShowPanel()
    {
        _signPanel.gameObject.SetActive(true);
        _panelActive = true;
    }

    private void HidePanel()
    {
        _signPanel.gameObject.SetActive(false);
        _panelActive = false;
        for (int i = 0; i < _signID; i++)
        {
            _images[i].color = new Color(0f, 0f, 0f, 1f);
        }
        _timerBool = false;
        _timeCount = 0;
    }

    private void ShowEKeyboard()
    {
        _eKeyboard.gameObject.SetActive(true);
    }

    private void HideEKeyboard()
    {
        _eKeyboard.gameObject.SetActive(false);
    }

    private IEnumerator WaitTime()
    {
        yield return new WaitForSeconds(_time);
        _timeBool = true;
    }

}
